summaryrefslogtreecommitdiff
path: root/src/glibext
diff options
context:
space:
mode:
authorCyrille Bagard <nocbos@gmail.com>2015-07-16 00:17:48 (GMT)
committerCyrille Bagard <nocbos@gmail.com>2015-07-16 00:17:48 (GMT)
commita61f089babe336b012da31a494b0f7470b6e1a9a (patch)
tree0dccd2fe50375e84de49b1119a3feec68b6bd23d /src/glibext
parent46c8fd10ec5bff1ee1146a0b6a7aa7eb9f47a2da (diff)
Used the binary contents a little bit more.
git-svn-id: svn://svn.gna.org/svn/chrysalide/trunk@551 abbe820e-26c8-41b2-8c08-b7b2b41f8b0a
Diffstat (limited to 'src/glibext')
-rw-r--r--src/glibext/gbincontent.c23
-rw-r--r--src/glibext/gbincontent.h3
2 files changed, 25 insertions, 1 deletions
diff --git a/src/glibext/gbincontent.h b/src/glibext/gbincontent.h
index 246d626..9dd7264 100644
--- a/src/glibext/gbincontent.h
+++ b/src/glibext/gbincontent.h
@@ -59,6 +59,9 @@ GBinContent *g_binary_content_new_from_file(const char *);
/* Fournit une empreinte unique (SHA256) pour les données. */
const gchar *g_binary_content_get_cheksum(GBinContent *);
+/* Détermine le nombre d'octets lisibles. */
+phys_t g_binary_content_compute_size(const GBinContent *);
+
/* Fournit une portion des données représentées. */
bool g_binary_content_get_raw(const GBinContent *, vmpa2t *, phys_t, bin_t *);
diff --git a/src/glibext/gbincontent.c b/src/glibext/gbincontent.c
index a9fe907..4ea0b03 100644
--- a/src/glibext/gbincontent.c
+++ b/src/glibext/gbincontent.c
@@ -257,7 +257,7 @@ GBinContent *g_binary_content_new_from_file(const char *filename)
/******************************************************************************
* *
* Paramètres : binary = contenu binaire à consulter. *
* *
* Description : Fournit une empreinte unique (SHA256) pour les données. *
* *
@@ -292,10 +292,31 @@ const gchar *g_binary_content_get_cheksum(GBinContent *content)
+/******************************************************************************
+* *
+* Paramètres : content = contenu binaire à venir lire. *
+* *
+* Description : Détermine le nombre d'octets lisibles. *
+* *
+* Retour : Quantité représentée. *
+* *
+* Remarques : - *
+* *
+******************************************************************************/
+
+phys_t g_binary_content_compute_size(const GBinContent *content)
+{
+ phys_t result; /* Quantité trouvée à retourner*/
+ size_t i; /* Boucle de parcours */
+ result = 0;
+ for (i = 0; i < content->count; i++)
+ result = get_mrange_length(&content->parts[i].range);
+ return result;
+}
/******************************************************************************
@@ -257,7 +257,7 @@ GBinContent *g_binary_content_new_from_file(const char *filename)
/******************************************************************************
* *
-* Paramètres : binary = contenu binaire à consulter. *
+* Paramètres : content = contenu binaire à venir lire. *
* *
* Description : Fournit une empreinte unique (SHA256) pour les données. *